@@ -48,7 +48,10 @@ class AWSGroup(JSONable):
     # ----------------------------------------------------------------------------------------------------------------
 
     def get_group_info_from_name(self):
-        response = self.__client.list_groups()
+        response = self.__client.list_groups(MaxResults='1000')     # NextToken='string'
+
+        # print("response...", file=sys.stderr)
+        # print(response, file=sys.stderr)
 
         d_groups = PathDict(response)
         g_node = d_groups.node("Groups")
