@@ -92,10 +92,15 @@ class S3Manager(object):
 
     def retrieve_from_bucket(self, bucket, key):
         response = self.__client.get_object(Bucket=bucket, Key=key)
-        content_body = response.get("Body")
-        data = content_body.read()
 
-        return data.decode()
+        meta = response.get('ResponseMetadata')
+        header = meta.get('HTTPHeaders')
+        last_modified = LocalizedDatetime.construct_from_s3(header.get('last-modified'))
+
+        content_body = response.get("Body")
+        data = content_body.read().decode()
+
+        return data, last_modified
 
 
     def upload_file_to_bucket(self, filepath, bucket, key):
@@ -224,6 +229,13 @@ class S3PersistenceManager(PersistenceManager):
 
     # ----------------------------------------------------------------------------------------------------------------
 
+    def list(self, container, dirname):
+        prefix_len = len(dirname) + 1
+        objects = self.__manager.list_objects(container, 1, True, prefix=dirname)
+
+        return [obj.key[prefix_len:] for obj in objects]
+
+
     def exists(self, dirname, filename):
         key = self.__key(dirname, filename)
 
@@ -233,7 +245,7 @@ class S3PersistenceManager(PersistenceManager):
     def load(self, dirname, filename, encryption_key=None):
         key = self.__key(dirname, filename)
 
-        text = self.__manager.retrieve_from_bucket(self.__BUCKET, key)
+        text, last_modified = self.__manager.retrieve_from_bucket(self.__BUCKET, key)
 
         if encryption_key:
             from scs_core.data.crypt import Crypt               # late import
@@ -241,7 +253,7 @@ class S3PersistenceManager(PersistenceManager):
         else:
             jstr = text
 
-        return jstr
+        return jstr, last_modified
 
 
     def save(self, jstr, dirname, filename, encryption_key=None):
@@ -262,6 +274,13 @@ class S3PersistenceManager(PersistenceManager):
         self.__manager.delete_object(self.__BUCKET, key)
 
 
+    # ----------------------------------------------------------------------------------------------------------------
+
+    @classmethod
+    def scs_path(cls):
+        return cls.__BUCKET
+
+
     # ----------------------------------------------------------------------------------------------------------------
 
     def __str__(self, *args, **kwargs):
