@@ -11,6 +11,7 @@ import os
 import sys
 
 from scs_core.csv.csv_dict import CSVDict
+from scs_core.data.path_dict import PathDict
 
 
 # --------------------------------------------------------------------------------------------------------------------
@@ -20,30 +21,30 @@ class CSVWriter(object):
     classdocs
     """
 
-    QUOTING = csv.QUOTE_MINIMAL
-
     # ----------------------------------------------------------------------------------------------------------------
 
-    def __init__(self, filename=None, append=False, exclude_header=False, header_scan=False):
+    def __init__(self, filename=None, append=False, exclude_header=False, header_scan=False, quote_all=False):
         """
         Constructor
         """
         self.__filename = filename
         self.__paths = []
 
+        quoting = csv.QUOTE_ALL if quote_all else csv.QUOTE_MINIMAL
+
         if self.__filename is None:
             self.__append = append
 
             self.__file = sys.stdout
-            self.__writer = csv.writer(self.__file, quoting=self.QUOTING)
+            self.__writer = csv.writer(self.__file, quoting=quoting)
         else:
             self.__append = append and os.path.exists(self.__filename)
 
             if self.__append and not header_scan:
-                self.__paths = self.__append_paths()
+                self.__paths = self.__build_paths()
 
             self.__file = open(self.__filename, "a" if self.__append else "w", newline='')
-            self.__writer = csv.writer(self.__file, quoting=self.QUOTING)
+            self.__writer = csv.writer(self.__file, quoting=quoting)
 
         self.__exclude_header = exclude_header
         self.__header_scan = header_scan
@@ -51,19 +52,6 @@ class CSVWriter(object):
         self.__data = []
 
 
-    # ----------------------------------------------------------------------------------------------------------------
-
-    def __append_paths(self):
-        file = sys.stdin if self.__filename is None else open(self.__filename, "r")
-        reader = csv.reader(file)
-
-        paths = next(reader)
-
-        file.close()
-
-        return paths
-
-
     # ----------------------------------------------------------------------------------------------------------------
 
     def write(self, jstr):
@@ -77,10 +65,7 @@ class CSVWriter(object):
 
         if self.__header_scan:
             self.__data.append(datum)
-
-            for path in datum.paths():
-                if path not in self.__paths:
-                    self.__paths.append(path)
+            self.__update_paths(datum)
 
             return True
 
@@ -113,6 +98,46 @@ class CSVWriter(object):
         self.__file.close()
 
 
+    # ----------------------------------------------------------------------------------------------------------------
+
+    def __build_paths(self):
+        file = sys.stdin if self.__filename is None else open(self.__filename, "r")
+        reader = csv.reader(file)
+
+        paths = next(reader)
+
+        file.close()
+
+        return paths
+
+
+    def __update_paths(self, datum):
+        datum_paths = datum.paths()
+
+        appended_paths = []
+        for i in range(len(datum_paths)):
+            if datum_paths[i] not in self.__paths and not self.__is_sub_path(datum_paths[i], self.__paths):
+                self.__paths.insert(i, datum_paths[i])
+                appended_paths.append(datum_paths[i])
+
+        if appended_paths:
+            for i in reversed(range(len(self.__paths))):
+                if self.__is_sub_path(self.__paths[i], appended_paths):
+                    self.__paths.pop(i)
+
+
+    @staticmethod
+    def __is_sub_path(candidate, paths):
+        for path in paths:
+            if candidate == path:
+                return False            # exit here because paths are assumed to be unique
+
+            if PathDict.sub_path_includes_path(candidate, path):
+                return True
+
+        return False
+
+
     # ----------------------------------------------------------------------------------------------------------------
 
     @property
