@@ -12,8 +12,6 @@ from decimal import InvalidOperation
 
 from scs_core.data.categorical_regression import CategoricalRegression
 from scs_core.data.datetime import LocalizedDatetime
-from scs_core.data.datum import Datum
-from scs_core.data.json import JSONify
 from scs_core.data.linear_regression import LinearRegression
 from scs_core.data.path_dict import PathDict
 from scs_core.data.precision import Precision
@@ -78,8 +76,8 @@ class Aggregate(object):
                         continue
 
                     self.__precisions[path] = Precision()
-                    self.__regressions[path] = LinearRegression() if Datum.is_numeric(sample.node(path)) else \
-                        CategoricalRegression()
+                    self.__regressions[path] = CategoricalRegression() if isinstance(sample.node(path), str) else \
+                        LinearRegression()
 
             self.__initialised = True
 
@@ -120,27 +118,17 @@ class Aggregate(object):
             regression = self.__regressions[path]
 
             if self.__regressions[path].has_midpoint():
-                _, midpoint = regression.midpoint(precision.digits)
-
                 if self.__min_max:
                     report.append(path + '.min', regression.min(precision.digits))
-                    report.append(path + '.mid', midpoint)
+                    report.append(path + '.mid', regression.mid(precision.digits))
                     report.append(path + '.max', regression.max(precision.digits))
 
                 else:
-                    report.append(path, midpoint)
+                    report.append(path, regression.mid(precision.digits))
 
         return report
 
 
-    def print(self, localised_datetime):
-        print(JSONify.dumps(self.report(localised_datetime)))
-        sys.stdout.flush()
-
-    def pass_back(self, localised_datetime):
-        return JSONify.dumps(self.report(localised_datetime))
-
-
     # ----------------------------------------------------------------------------------------------------------------
 
     def complies_with_rule(self, sampling_interval, aggregate_interval):
