@@ -4,15 +4,15 @@ Created on 24 Sep 2016
 @author: Bruno Beloff (bruno.beloff@southcoastscience.com)
 
 https://docs.python.org/3/library/struct.html
+https://stackoverflow.com/questions/8022530/how-to-check-for-valid-email-address
 """
 
 import math
+import re
 import struct
 
 from datetime import date
 
-from scs_core.data.datetime import LocalizedDatetime
-
 
 # --------------------------------------------------------------------------------------------------------------------
 
@@ -46,6 +46,14 @@ class Datum(object):
     # ----------------------------------------------------------------------------------------------------------------
     # morphological numeracy...
 
+    @classmethod
+    def is_email_address(cls, value):
+        try:
+            return bool(re.match(r'[^@\s]+@[^@\s]+\.[^@\s]+', value))
+        except TypeError:
+            return False
+
+
     @classmethod
     def is_numeric(cls, value):
         return cls.precision(value) is not None
@@ -76,6 +84,9 @@ class Datum(object):
         if value is None:
             return None
 
+        if isinstance(value, bool):
+            return None
+
         try:
             float(value)
         except ValueError:
@@ -153,19 +164,6 @@ class Datum(object):
         return date(year, month, day)
 
 
-    @staticmethod
-    def datetime(iso_datetime):
-        if iso_datetime is None:
-            return None
-
-        try:
-            value = LocalizedDatetime.construct_from_iso8601(iso_datetime)
-        except (TypeError, ValueError):
-            return None
-
-        return value
-
-
 # --------------------------------------------------------------------------------------------------------------------
 
 class Encode(object):
