@@ -44,7 +44,7 @@ class GasesSample(Sample):
     __VOC_FIELDS = ['VOC']
 
     @classmethod
-    def construct_from_jdict(cls, jdict, default=True):
+    def construct_from_jdict(cls, jdict, skeleton=False):
         if not jdict:
             return None
 
