@@ -28,7 +28,7 @@ class ParticulatesSample(Sample):
     """
 
     @classmethod
-    def construct_from_jdict(cls, jdict, default=True):
+    def construct_from_jdict(cls, jdict, skeleton=False):
         if not jdict:
             return None
 
